Riverbed SteelScript for SteelCentral Controller
================================================

This package provides device specific bindings for interacting
with Riverbed SteelCentral Controller devices as part of the Riverbed
Steelscript for Python.

License
=======

Copyright (c) 2015 Riverbed Technology, Inc.

SteelScript-SCC is licensed under the terms and conditions of the MIT
License accompanying the software ("License").  SteelScript-SCC is
distributed "AS IS" as set forth in the License.

